@@ -30,7 +30,7 @@ get_daily_data <- function(cookie, what="steps", start_date, end_date){
 
   if(what=="getTimeInHeartRateZonesPerDay"){
     url <- "https://www.fitbit.com/ajaxapi"
-    request <- paste0('{"template":"/mgmt/ajaxTemplate.jsp","serviceCalls":[{"name":"activityTileData","args":{"startDate":"',
+    request <- paste0('{"template":"/ajaxTemplate.jsp","serviceCalls":[{"name":"activityTileData","args":{"startDate":"',
                       start_date,
                       '","endDate":"',
                       end_date,
